@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -45,6 +45,7 @@ extern "C"
 {
 #endif
 
+#ifndef MINISIZE
 /**
  * Allocate a To element.
  * @param header The element to work on.
@@ -73,6 +74,21 @@ extern "C"
  * @param dest A pointer on the copy of the element.
  */
   int osip_to_clone (const osip_to_t * header, osip_to_t ** dest);
+/**
+ * Check if the tags in the To headers match.
+ * NOTE: THIS IS AN INTERNAL METHOD ONLY
+ * @param to1 The first To header.
+ * @param to2 The second To header.
+ */
+  int osip_to_tag_match (osip_to_t * to1, osip_to_t * to2);
+#else
+  #define osip_to_init   osip_from_init
+  #define osip_to_free   osip_from_free
+  #define osip_to_parse  osip_from_parse
+  #define osip_to_to_str osip_from_to_str
+  #define osip_to_clone  osip_from_clone
+  #define osip_to_tag_match osip_from_tag_match
+#endif
 /**
  * Set the displayname in the To element.
  * @param header The element to work on.
@@ -135,14 +151,6 @@ extern "C"
 #define osip_to_compare(header1, header2) osip_from_compare((osip_from_t *)header1, (osip_from_t *)header2)
 #endif
 
-/**
- * Check if the tags in the To headers match.
- * NOTE: THIS IS AN INTERNAL METHOD ONLY
- * @param to1 The first To header.
- * @param to2 The second To header.
- */
-  int osip_to_tag_match (osip_to_t * to1, osip_to_t * to2);
-
 #ifdef __cplusplus
 }
 #endif
