@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -87,7 +87,7 @@ extern "C"
   {
     char *t_start_time;            /**< start time */
     char *t_stop_time;             /**< stop time */
-    osip_list_t *r_repeats;        /**< repeat headers */
+    osip_list_t r_repeats;        /**< repeat headers */
   };
 
 /**
@@ -113,8 +113,8 @@ extern "C"
  */
   struct sdp_key
   {
-    char *k_keytype;	/**< Key Type (prompt, clear, base64, uri) */
-    char *k_keydata;	/**< key data */
+    char *k_keytype;    /**< Key Type (prompt, clear, base64, uri) */
+    char *k_keydata;    /**< key data */
   };
 
 /**
@@ -141,7 +141,7 @@ extern "C"
   struct sdp_attribute
   {
     char *a_att_field;          /**< attribute field */
-    char *a_att_value;	        /**< attribute value (optional) */
+    char *a_att_value;          /**< attribute value (optional) */
   };
 
 /**
@@ -171,8 +171,8 @@ extern "C"
     char *c_nettype;             /**< Network Type */
     char *c_addrtype;            /**< Network Address Type */
     char *c_addr;                /**< Address */
-    char *c_addr_multicast_ttl;	 /**< TTL value for multicast address */
-    char *c_addr_multicast_int;	 /**< Number of multicast address */
+    char *c_addr_multicast_ttl;  /**< TTL value for multicast address */
+    char *c_addr_multicast_int;  /**< Number of multicast address */
   };
 
 /**
@@ -202,12 +202,12 @@ extern "C"
     char *m_port;               /**< port number */
     char *m_number_of_port;     /**< number of port */
     char *m_proto;              /**< protocol to be used */
-    osip_list_t *m_payloads;    /**< list of payloads (as strings) */
+    osip_list_t m_payloads;    /**< list of payloads (as strings) */
 
     char *i_info;               /**< information header */
-    osip_list_t *c_connections;	/**< list of sdp_connection_t * */
-    osip_list_t *b_bandwidths;	/**< list of sdp_bandwidth_t * */
-    osip_list_t *a_attributes;	/**< list of sdp_attribute_t * */
+    osip_list_t c_connections; /**< list of sdp_connection_t * */
+    osip_list_t b_bandwidths;  /**< list of sdp_bandwidth_t * */
+    osip_list_t a_attributes;  /**< list of sdp_attribute_t * */
     sdp_key_t *k_key;           /**< key informations */
   };
 
@@ -244,15 +244,15 @@ extern "C"
     char *s_name;               /**< Subject header */
     char *i_info;               /**< Information header */
     char *u_uri;                /**< Uri header */
-    osip_list_t *e_emails;	/**< list of mail address */
-    osip_list_t *p_phones;	/**< list of phone numbers * */
+    osip_list_t e_emails;      /**< list of mail address */
+    osip_list_t p_phones;      /**< list of phone numbers * */
     sdp_connection_t *c_connection;   /**< Connection information */
-    osip_list_t *b_bandwidths;	/**< list of bandwidth info (sdp_bandwidth_t) */
-    osip_list_t *t_descrs;	/**< list of time description (sdp_time_descr_t) */
+    osip_list_t b_bandwidths;  /**< list of bandwidth info (sdp_bandwidth_t) */
+    osip_list_t t_descrs;      /**< list of time description (sdp_time_descr_t) */
     char *z_adjustments;        /**< Time adjustment header */
     sdp_key_t *k_key;           /**< Key information header */
-    osip_list_t *a_attributes;	/**< list of global attributes (sdp_attribute_t) */
-    osip_list_t *m_medias;	/**< list of supported media (sdp_media_t) */
+    osip_list_t a_attributes;  /**< list of global attributes (sdp_attribute_t) */
+    osip_list_t m_medias;      /**< list of supported media (sdp_media_t) */
   };
 
 
@@ -308,8 +308,8 @@ extern "C"
  * @param addr The token value.
  */
   int sdp_message_o_origin_set (sdp_message_t * sdp, char *username,
-				char *sess_id, char *sess_version,
-				char *nettype, char *addrtype, char *addr);
+                                char *sess_id, char *sess_version,
+                                char *nettype, char *addrtype, char *addr);
 /**
  * Get the username ('o' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -357,8 +357,7 @@ extern "C"
  * @param pos_media The media line number.
  * @param value The token value.
  */
-  int sdp_message_i_info_set (sdp_message_t * sdp, int pos_media,
-			      char *value);
+  int sdp_message_i_info_set (sdp_message_t * sdp, int pos_media, char *value);
 /**
  * Get the session info ('i' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -386,7 +385,7 @@ extern "C"
  * OBSOLETE: see sdp_message_e_email_get
  * @def sdp_e_email_get
  */
-  #define sdp_e_email_get sdp_message_e_email_get
+#define sdp_e_email_get sdp_message_e_email_get
 /**
  * Get one of the email ('e' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -416,13 +415,13 @@ extern "C"
  * @param addr_multicast_int The token value.
  */
   int sdp_message_c_connection_add (sdp_message_t * sdp, int pos_media,
-				    char *nettype, char *addrtype,
-				    char *addr, char *addr_multicast_ttl,
-				    char *addr_multicast_int);
+                                    char *nettype, char *addrtype,
+                                    char *addr, char *addr_multicast_ttl,
+                                    char *addr_multicast_int);
 #ifndef DOXYGEN
 /* this method should be internal only... */
   sdp_connection_t *sdp_message_connection_get (sdp_message_t * sdp,
-						int pos_media, int pos);
+                                                int pos_media, int pos);
 #endif
 /**
  * Get the network type ('c' field) of a SDP packet.
@@ -430,16 +429,14 @@ extern "C"
  * @param pos_media The media line number.
  * @param pos The index in the connection element list..
  */
-  char *sdp_message_c_nettype_get (sdp_message_t * sdp, int pos_media,
-				   int pos);
+  char *sdp_message_c_nettype_get (sdp_message_t * sdp, int pos_media, int pos);
 /**
  * Get the address type ('c' field) of a SDP packet.
  * @param sdp The element to work on.
  * @param pos_media The media line number.
  * @param pos The index in the connection element list..
  */
-  char *sdp_message_c_addrtype_get (sdp_message_t * sdp, int pos_media,
-				    int pos);
+  char *sdp_message_c_addrtype_get (sdp_message_t * sdp, int pos_media, int pos);
 /**
  * Get the address ('c' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -454,7 +451,7 @@ extern "C"
  * @param pos The index in the connection element list..
  */
   char *sdp_message_c_addr_multicast_ttl_get (sdp_message_t * sdp,
-					      int pos_media, int pos);
+                                              int pos_media, int pos);
 /**
  * Get the multicast int info ('c' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -462,7 +459,7 @@ extern "C"
  * @param pos The index in the connection element list..
  */
   char *sdp_message_c_addr_multicast_int_get (sdp_message_t * sdp,
-					      int pos_media, int pos);
+                                              int pos_media, int pos);
 /**
  * Set the version in a SDP packet.
  * @param sdp The element to work on.
@@ -471,7 +468,7 @@ extern "C"
  * @param bandwidth The token value.
  */
   int sdp_message_b_bandwidth_add (sdp_message_t * sdp, int pos_media,
-				   char *bwtype, char *bandwidth);
+                                   char *bwtype, char *bandwidth);
 /**
  * Get the bandwidth ('b' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -479,31 +476,28 @@ extern "C"
  * @param pos The index in the bandwidth element list..
  */
   sdp_bandwidth_t *sdp_message_bandwidth_get (sdp_message_t * sdp,
-					      int pos_media, int pos);
+                                              int pos_media, int pos);
 /**
  * Get the bandwidth type ('b' field) of a SDP packet.
  * @param sdp The element to work on.
  * @param pos_media The media line number.
  * @param pos The index in the bandwidth element list..
  */
-  char *sdp_message_b_bwtype_get (sdp_message_t * sdp, int pos_media,
-				  int pos);
+  char *sdp_message_b_bwtype_get (sdp_message_t * sdp, int pos_media, int pos);
 /**
  * Get the bandwidth value ('b' field) of a SDP packet.
  * @param sdp The element to work on.
  * @param pos_media The media line number.
  * @param pos The index in the bandwidth element list..
  */
-  char *sdp_message_b_bandwidth_get (sdp_message_t * sdp, int pos_media,
-				     int pos);
+  char *sdp_message_b_bandwidth_get (sdp_message_t * sdp, int pos_media, int pos);
 /**
  * Set the version in a SDP packet.
  * @param sdp The element to work on.
  * @param start The token value.
  * @param stop The token value.
  */
-  int sdp_message_t_time_descr_add (sdp_message_t * sdp, char *start,
-				    char *stop);
+  int sdp_message_t_time_descr_add (sdp_message_t * sdp, char *start, char *stop);
 /**
  * Get the start time value ('t' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -523,7 +517,7 @@ extern "C"
  * @param value The token value.
  */
   int sdp_message_r_repeat_add (sdp_message_t * sdp, int pos_time_descr,
-				char *value);
+                                char *value);
 /**
  * Get the repeat information ('r' field) in a SDP packet.
  * @param sdp The element to work on.
@@ -531,7 +525,7 @@ extern "C"
  * @param pos_repeat index of element in the 'r' field.
  */
   char *sdp_message_r_repeat_get (sdp_message_t * sdp, int pos_time_descr,
-				  int pos_repeat);
+                                  int pos_repeat);
 /**
  * Set the adjustments ('z' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -551,7 +545,7 @@ extern "C"
  * @param keydata The token value.
  */
   int sdp_message_k_key_set (sdp_message_t * sdp, int pos_media,
-			     char *keytype, char *keydata);
+                             char *keytype, char *keydata);
 /**
  * Get the key type ('k' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -572,15 +566,15 @@ extern "C"
  * @param att_value The token value.
  */
   int sdp_message_a_attribute_add (sdp_message_t * sdp, int pos_media,
-				   char *att_field, char *att_value);
+                                   char *att_field, char *att_value);
 /**
  * delete all attribute fields specified by att_field.
  * @param sdp The element to work on.
  * @param pos_media The line number.
  * @param att_field The value to remove.
  */
-  int sdp_message_a_attribute_del (sdp_message_t * sdp, int pos_media, 
-				   char *att_field);
+  int sdp_message_a_attribute_del (sdp_message_t * sdp, int pos_media,
+                                   char *att_field);
 /**
  * delete one specific attribute fields specified by att_field.
  * @param sdp The element to work on.
@@ -588,8 +582,9 @@ extern "C"
  * @param att_field The value to remove.
  * @param pos_attr The index of attribute to remove.
  */
-  int sdp_message_a_attribute_del_at_index (sdp_message_t * sdp, int pos_media, 
-					    char *att_field, int pos_attr);
+  int sdp_message_a_attribute_del_at_index (sdp_message_t * sdp,
+                                            int pos_media, char *att_field,
+                                            int pos_attr);
  /**
  * Get one of the attribute ('a' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -597,23 +592,21 @@ extern "C"
  * @param pos The attribute line number.
  */
   sdp_attribute_t *sdp_message_attribute_get (sdp_message_t * sdp,
-					      int pos_media, int pos);
+                                              int pos_media, int pos);
 /**
  * Get the attribute name ('a' field) of a SDP packet.
  * @param sdp The element to work on.
  * @param pos_media The media line number.
  * @param pos The attribute line number.
  */
-  char *sdp_message_a_att_field_get (sdp_message_t * sdp, int pos_media,
-				     int pos);
+  char *sdp_message_a_att_field_get (sdp_message_t * sdp, int pos_media, int pos);
 /**
  * Get the attribute value ('a' field) of a SDP packet.
  * @param sdp The element to work on.
  * @param pos_media The media line number.
  * @param pos The attribute line number.
  */
-  char *sdp_message_a_att_value_get (sdp_message_t * sdp, int pos_media,
-				     int pos);
+  char *sdp_message_a_att_value_get (sdp_message_t * sdp, int pos_media, int pos);
 /**
  * Check if there is more media lines a SDP packet.
  * @param sdp The element to work on.
@@ -629,7 +622,7 @@ extern "C"
  * @param proto The token value.
  */
   int sdp_message_m_media_add (sdp_message_t * sdp, char *media,
-			       char *port, char *number_of_port, char *proto);
+                               char *port, char *number_of_port, char *proto);
 /**
  * Get the media type ('m' field) of a SDP packet.
  * @param sdp The element to work on.
@@ -668,23 +661,21 @@ extern "C"
  * @param payload The token value.
  */
   int sdp_message_m_payload_add (sdp_message_t * sdp, int pos_media,
-				 char *payload);
+                                 char *payload);
 /**
  * Get one of the payload number ('m' field) of a SDP packet.
  * @param sdp The element to work on.
  * @param pos_media The line number.
  * @param pos The i th payload element.
  */
-  char *sdp_message_m_payload_get (sdp_message_t * sdp, int pos_media,
-				   int pos);
+  char *sdp_message_m_payload_get (sdp_message_t * sdp, int pos_media, int pos);
 /**
  * Remove a payload in a SDP packet.
  * @param sdp The element to work on.
  * @param pos_media The line number.
  * @param pos The position of the payload in the media line.
  */
-  int sdp_message_m_payload_del (sdp_message_t * sdp, int pos_media,
- 				 int pos);
+  int sdp_message_m_payload_del (sdp_message_t * sdp, int pos_media, int pos);
 
 
 /** @} */
