@@ -35,7 +35,7 @@ __osip_ict_init (osip_ict_t ** ict, osip_t * osip, osip_message_t * invite)
 
   *ict = (osip_ict_t *) osip_malloc (sizeof (osip_ict_t));
   if (*ict == NULL)
-    return -1;
+    return OSIP_NOMEM;
 
   now = time (NULL);
   memset (*ict, 0, sizeof (osip_ict_t));
@@ -45,11 +45,17 @@ __osip_ict_init (osip_ict_t ** ict, osip_t * osip, osip_message_t * invite)
     char *proto;
 
     i = osip_message_get_via (invite, 0, &via); /* get top via */
-    if (i != 0)
-      goto ii_error_1;
+    if (i < 0)
+	{
+	  osip_free (*ict);
+	  return i;
+	}
     proto = via_get_protocol (via);
     if (proto == NULL)
-      goto ii_error_1;
+	{
+	  osip_free (*ict);
+	  return OSIP_SYNTAXERROR;
+	}
 
     if (osip_strcasecmp (proto, "TCP") != 0
         && osip_strcasecmp (proto, "TLS") != 0
@@ -119,36 +125,32 @@ __osip_ict_init (osip_ict_t ** ict, osip_t * osip, osip_message_t * invite)
   /* Oups! A bug! */
   /*  (*ict)->port  = 5060; */
 
-  return 0;
-
-ii_error_1:
-  osip_free (*ict);
-  return -1;
+  return OSIP_SUCCESS;
 }
 
 int
 __osip_ict_free (osip_ict_t * ict)
 {
   if (ict == NULL)
-    return -1;
+    return OSIP_SUCCESS;
   OSIP_TRACE (osip_trace
               (__FILE__, __LINE__, OSIP_INFO2, NULL, "free ict ressource\n"));
 
   osip_free (ict->destination);
   osip_free (ict);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
 osip_ict_set_destination (osip_ict_t * ict, char *destination, int port)
 {
   if (ict == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (ict->destination != NULL)
     osip_free (ict->destination);
   ict->destination = destination;
   ict->port = port;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 osip_event_t *
