@@ -35,7 +35,7 @@ __osip_nict_init (osip_nict_t ** nict, osip_t * osip, osip_message_t * request)
 
   *nict = (osip_nict_t *) osip_malloc (sizeof (osip_nict_t));
   if (*nict == NULL)
-    return -1;
+    return OSIP_NOMEM;
   now = time (NULL);
   memset (*nict, 0, sizeof (osip_nict_t));
   /* for REQUEST retransmissions */
@@ -44,11 +44,19 @@ __osip_nict_init (osip_nict_t ** nict, osip_t * osip, osip_message_t * request)
     char *proto;
 
     i = osip_message_get_via (request, 0, &via);        /* get top via */
-    if (i != 0)
-      goto ii_error_1;
+    if (i < 0)
+	{
+		osip_free (*nict);
+		*nict=NULL;
+		return i;
+	}
     proto = via_get_protocol (via);
     if (proto == NULL)
-      goto ii_error_1;
+	{
+		osip_free (*nict);
+		*nict=NULL;
+		return OSIP_UNDEFINED_ERROR;
+	}
 
     if (osip_strcasecmp (proto, "TCP") != 0
         && osip_strcasecmp (proto, "TLS") != 0
@@ -115,36 +123,32 @@ __osip_nict_init (osip_nict_t ** nict, osip_t * osip, osip_message_t * request)
   /* Oups! a Bug! */
   /*  (*nict)->port  = 5060; */
 
-  return 0;
-
-ii_error_1:
-  osip_free (*nict);
-  return -1;
+  return OSIP_SUCCESS;
 }
 
 int
 __osip_nict_free (osip_nict_t * nict)
 {
   if (nict == NULL)
-    return -1;
+    return OSIP_SUCCESS;
   OSIP_TRACE (osip_trace
               (__FILE__, __LINE__, OSIP_INFO2, NULL, "free nict ressource\n"));
 
   osip_free (nict->destination);
   osip_free (nict);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
 osip_nict_set_destination (osip_nict_t * nict, char *destination, int port)
 {
   if (nict == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (nict->destination != NULL)
     osip_free (nict->destination);
   nict->destination = destination;
   nict->port = port;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 osip_event_t *
