@@ -61,7 +61,7 @@ osip_gettimeofday (struct timeval *tp, void *tz)
   DWORD timemillis = GetTickCount();
   tp->tv_sec  = timemillis/1000;
   tp->tv_usec = (timemillis - (tp->tv_sec*1000)) * 1000;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 time_t
@@ -89,7 +89,7 @@ osip_gettimeofday (struct timeval *tp, void *tz)
   _ftime (&timebuffer);
   tp->tv_sec = (long) timebuffer.time;
   tp->tv_usec = timebuffer.millitm * 1000;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 #endif
