@@ -37,20 +37,20 @@ osip_message_set_accept_encoding (osip_message_t * sip, const char *hvalue)
   int i;
 
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;
+    return OSIP_SUCCESS;
 
   i = osip_accept_encoding_init (&accept_encoding);
   if (i != 0)
-    return -1;
+    return i;
   i = osip_accept_encoding_parse (accept_encoding, hvalue);
   if (i != 0)
     {
       osip_accept_encoding_free (accept_encoding);
-      return -1;
+      return i;
     }
   sip->message_property = 2;
   osip_list_add (&sip->accept_encodings, accept_encoding, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -61,7 +61,7 @@ osip_message_get_accept_encoding (const osip_message_t * sip, int pos,
 
   *dest = NULL;
   if (osip_list_size (&sip->accept_encodings) <= pos)
-    return -1;                  /* does not exist */
+    return OSIP_UNDEFINED_ERROR;     /* does not exist */
   accept_encoding =
     (osip_accept_encoding_t *) osip_list_get (&sip->accept_encodings, pos);
   *dest = accept_encoding;
@@ -74,40 +74,42 @@ osip_accept_encoding_init (osip_accept_encoding_t ** accept_encoding)
   *accept_encoding =
     (osip_accept_encoding_t *) osip_malloc (sizeof (osip_accept_encoding_t));
   if (*accept_encoding == NULL)
-    return -1;
+    return OSIP_NOMEM;
   (*accept_encoding)->element = NULL;
 
   osip_list_init (&(*accept_encoding)->gen_params);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
 osip_accept_encoding_parse (osip_accept_encoding_t * accept_encoding,
                             const char *hvalue)
 {
+  int i;
   const char *osip_accept_encoding_params;
 
   osip_accept_encoding_params = strchr (hvalue, ';');
 
   if (osip_accept_encoding_params != NULL)
     {
-      if (__osip_generic_param_parseall (&accept_encoding->gen_params,
-                                         osip_accept_encoding_params) == -1)
-        return -1;
+		i = __osip_generic_param_parseall (&accept_encoding->gen_params,        
+                                 osip_accept_encoding_params);
+		if (i != 0)
+			return i;
   } else
     osip_accept_encoding_params = hvalue + strlen (hvalue);
 
   if (osip_accept_encoding_params - hvalue + 1 < 2)
-    return -1;
+    return OSIP_SYNTAXERROR;
   accept_encoding->element =
     (char *) osip_malloc (osip_accept_encoding_params - hvalue + 1);
   if (accept_encoding->element == NULL)
-    return -1;
+    return OSIP_NOMEM;
   osip_clrncpy (accept_encoding->element, hvalue,
                 osip_accept_encoding_params - hvalue);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* returns the accept_encoding header as a string.  */
@@ -123,12 +125,12 @@ osip_accept_encoding_to_str (const osip_accept_encoding_t * accept_encoding,
 
   *dest = NULL;
   if ((accept_encoding == NULL) || (accept_encoding->element == NULL))
-    return -1;
+    return OSIP_BADPARAMETER;
 
   len = strlen (accept_encoding->element) + 2;
   buf = (char *) osip_malloc (len);
   if (buf == NULL)
-    return -1;
+    return OSIP_NOMEM;
 
   sprintf (buf, "%s", accept_encoding->element);
   {
@@ -157,7 +159,7 @@ osip_accept_encoding_to_str (const osip_accept_encoding_t * accept_encoding,
       }
   }
   *dest = buf;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* deallocates a osip_accept_encoding_t structure.  */
@@ -184,18 +186,18 @@ osip_accept_encoding_clone (const osip_accept_encoding_t * ctt,
 
   *dest = NULL;
   if (ctt == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (ctt->element == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   i = osip_accept_encoding_init (&ct);
   if (i != 0)                   /* allocation failed */
-    return -1;
+    return i;
   ct->element = osip_strdup (ctt->element);
-  if (ctt->element != NULL && ct->element == NULL)
+  if (ct->element == NULL)
     {
       osip_accept_encoding_free (ct);
-      return -1;
+      return OSIP_NOMEM;
     }
   {
     int pos = 0;
@@ -209,14 +211,14 @@ osip_accept_encoding_clone (const osip_accept_encoding_t * ctt,
         if (i != 0)
           {
             osip_accept_encoding_free (ct);
-            return -1;
+            return i;
           }
         osip_list_add (&ct->gen_params, dest_param, -1);
         pos++;
       }
   }
   *dest = ct;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 
