@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,7 @@
 #include <osipparser2/osip_parser.h>
 #include "parser.h"
 
+#ifndef MINISIZE
 
 int
 osip_message_set_accept_language (osip_message_t * sip, const char *hvalue)
@@ -33,20 +34,20 @@ osip_message_set_accept_language (osip_message_t * sip, const char *hvalue)
   int i;
 
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;
+    return OSIP_SUCCESS;
 
   i = osip_accept_language_init (&accept_language);
   if (i != 0)
-    return -1;
+    return i;
   i = osip_accept_language_parse (accept_language, hvalue);
   if (i != 0)
     {
       osip_accept_language_free (accept_language);
-      return -1;
+      return i;
     }
   sip->message_property = 2;
-  osip_list_add (sip->accept_languages, accept_language, -1);
-  return 0;
+  osip_list_add (&sip->accept_languages, accept_language, -1);
+  return OSIP_SUCCESS;
 }
 
 int
@@ -56,10 +57,12 @@ osip_message_get_accept_language (const osip_message_t * sip, int pos,
   osip_accept_language_t *accept_language;
 
   *dest = NULL;
-  if (osip_list_size (sip->accept_languages) <= pos)
-    return -1;                  /* does not exist */
+  if (osip_list_size (&sip->accept_languages) <= pos)
+    return OSIP_UNDEFINED_ERROR;     /* does not exist */
   accept_language =
-    (osip_accept_language_t *) osip_list_get (sip->accept_languages, pos);
+    (osip_accept_language_t *) osip_list_get (&sip->accept_languages, pos);
   *dest = accept_language;
   return pos;
 }
+
+#endif
