@@ -35,13 +35,13 @@ osip_authentication_info_init (osip_authentication_info_t ** dest)
     (osip_authentication_info_t *)
     osip_malloc (sizeof (osip_authentication_info_t));
   if (*dest == NULL)
-    return -1;
+    return OSIP_NOMEM;
   (*dest)->nextnonce = NULL;
   (*dest)->qop_options = NULL;
   (*dest)->rspauth = NULL;
   (*dest)->cnonce = NULL;
   (*dest)->nonce_count = NULL;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* fills the www-authenticate header of message.               */
@@ -55,23 +55,23 @@ osip_message_set_authentication_info (osip_message_t * sip, const char *hvalue)
   int i;
 
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;
+    return OSIP_SUCCESS;
 
   if (sip == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   i = osip_authentication_info_init (&authentication_info);
   if (i != 0)
-    return -1;
+    return i;
   i = osip_authentication_info_parse (authentication_info, hvalue);
   if (i != 0)
     {
       osip_authentication_info_free (authentication_info);
-      return -1;
+      return i;
     }
   sip->message_property = 2;
 
   osip_list_add (&sip->authentication_infos, authentication_info, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* fills the authentication_info strucuture.                      */
@@ -88,6 +88,7 @@ osip_authentication_info_parse (osip_authentication_info_t * ainfo,
 {
   const char *space;
   const char *next = NULL;
+  int i;
 
   space = hvalue;
 
@@ -95,47 +96,51 @@ osip_authentication_info_parse (osip_authentication_info_t * ainfo,
     {
       int parse_ok = 0;
 
-      if (__osip_quoted_string_set
-          ("nextnonce", space, &(ainfo->nextnonce), &next))
-        return -1;
+	  i = __osip_quoted_string_set("nextnonce", space, &(ainfo->nextnonce), &next);
+	  if (i!=0)
+        return i;
       if (next == NULL)
-        return 0;               /* end of header detected! */
+        return OSIP_SUCCESS;               /* end of header detected! */
       else if (next != space)
         {
           space = next;
           parse_ok++;
         }
-      if (__osip_quoted_string_set ("cnonce", space, &(ainfo->cnonce), &next))
-        return -1;
+      i = __osip_quoted_string_set ("cnonce", space, &(ainfo->cnonce), &next);
+	  if (i!=0)
+        return i;
       if (next == NULL)
-        return 0;               /* end of header detected! */
+        return OSIP_SUCCESS;               /* end of header detected! */
       else if (next != space)
         {
           space = next;
           parse_ok++;
         }
-      if (__osip_quoted_string_set ("rspauth", space, &(ainfo->rspauth), &next))
-        return -1;
+      i = __osip_quoted_string_set ("rspauth", space, &(ainfo->rspauth), &next);
+	  if (i!=0)
+        return i;
       if (next == NULL)
-        return 0;               /* end of header detected! */
+        return OSIP_SUCCESS;               /* end of header detected! */
       else if (next != space)
         {
           space = next;
           parse_ok++;
         }
-      if (__osip_token_set ("nc", space, &(ainfo->nonce_count), &next))
-        return -1;
+      i = __osip_token_set ("nc", space, &(ainfo->nonce_count), &next);
+	  if (i!=0)
+        return i;
       if (next == NULL)
-        return 0;               /* end of header detected! */
+        return OSIP_SUCCESS;               /* end of header detected! */
       else if (next != space)
         {
           space = next;
           parse_ok++;
         }
-      if (__osip_token_set ("qop", space, &(ainfo->qop_options), &next))
-        return -1;
+      i = __osip_token_set ("qop", space, &(ainfo->qop_options), &next);
+	  if (i!=0)
+        return i;
       if (next == NULL)
-        return 0;               /* end of header detected! */
+        return OSIP_SUCCESS;               /* end of header detected! */
       else if (next != space)
         {
           space = next;
@@ -149,28 +154,28 @@ osip_authentication_info_parse (osip_authentication_info_t * ainfo,
           /* parameter not understood!!! I'm too lazy to handle IT */
           /* let's simply bypass it */
           if (strlen (space) < 1)
-            return 0;
+            return OSIP_SUCCESS;
           tmp = strchr (space + 1, ',');
           if (tmp == NULL)      /* it was the last header */
-            return 0;
+            return OSIP_SUCCESS;
           quote1 = __osip_quote_find (space);
           if ((quote1 != NULL) && (quote1 < tmp))       /* this may be a quoted string! */
             {
               quote2 = __osip_quote_find (quote1 + 1);
               if (quote2 == NULL)
-                return -1;      /* bad header format... */
+                return OSIP_SYNTAXERROR;      /* bad header format... */
               if (tmp < quote2) /* the comma is inside the quotes! */
                 space = strchr (quote2, ',');
               else
                 space = tmp;
               if (space == NULL)        /* it was the last header */
-                return 0;
+                return OSIP_SUCCESS;
           } else
             space = tmp;
           /* continue parsing... */
         }
     }
-  return 0;                     /* ok */
+  return OSIP_SUCCESS;                     /* ok */
 }
 
 /* returns the authentication_info header.            */
@@ -184,7 +189,7 @@ osip_message_get_authentication_info (const osip_message_t * sip, int pos,
 
   *dest = NULL;
   if (osip_list_size (&sip->authentication_infos) <= pos)
-    return -1;                  /* does not exist */
+    return OSIP_UNDEFINED_ERROR;     /* does not exist */
 
   authentication_info =
     (osip_authentication_info_t *) osip_list_get (&sip->authentication_infos, pos);
@@ -277,7 +282,7 @@ osip_authentication_info_to_str (const osip_authentication_info_t * ainfo,
 
   *dest = NULL;
   if (ainfo == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   len = 0;
   if (ainfo->nextnonce != NULL)
@@ -292,11 +297,11 @@ osip_authentication_info_to_str (const osip_authentication_info_t * ainfo,
     len = len + strlen (ainfo->qop_options) + 6;
 
   if (len == 0)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   tmp = (char *) osip_malloc (len);
   if (tmp == NULL)
-    return -1;
+    return OSIP_NOMEM;
   *dest = tmp;
 
   if (ainfo->qop_options != NULL)
@@ -341,7 +346,7 @@ osip_authentication_info_to_str (const osip_authentication_info_t * ainfo,
       tmp = osip_str_append (tmp, ainfo->nonce_count);
     }
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* deallocates a osip_authentication_info_t structure.  */
@@ -369,11 +374,11 @@ osip_authentication_info_clone (const osip_authentication_info_t * ainfo,
 
   *dest = NULL;
   if (ainfo == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   i = osip_authentication_info_init (&wa);
-  if (i == -1)                  /* allocation failed */
-    return -1;
+  if (i != 0)                  /* allocation failed */
+    return i;
   if (ainfo->nextnonce != NULL)
     wa->nextnonce = osip_strdup (ainfo->nextnonce);
   if (ainfo->cnonce != NULL)
@@ -386,7 +391,7 @@ osip_authentication_info_clone (const osip_authentication_info_t * ainfo,
     wa->qop_options = osip_strdup (ainfo->qop_options);
 
   *dest = wa;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 #endif
