@@ -30,10 +30,10 @@ osip_cseq_init (osip_cseq_t ** cseq)
 {
   *cseq = (osip_cseq_t *) osip_malloc (sizeof (osip_cseq_t));
   if (*cseq == NULL)
-    return -1;
+    return OSIP_NOMEM;
   (*cseq)->method = NULL;
   (*cseq)->number = NULL;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* fills the cseq header of message.               */
@@ -46,22 +46,22 @@ osip_message_set_cseq (osip_message_t * sip, const char *hvalue)
   int i;
 
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;
+    return OSIP_SUCCESS;
 
   if (sip->cseq != NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   i = osip_cseq_init (&(sip->cseq));
   if (i != 0)
-    return -1;
+    return i;
   sip->message_property = 2;
   i = osip_cseq_parse (sip->cseq, hvalue);
   if (i != 0)
     {
       osip_cseq_free (sip->cseq);
       sip->cseq = NULL;
-      return -1;
+      return i;
     }
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* fills the cseq strucuture.                      */
@@ -74,30 +74,33 @@ osip_cseq_parse (osip_cseq_t * cseq, const char *hvalue)
   char *method = NULL;
   const char *end = NULL;
 
+  if (cseq==NULL || hvalue==NULL)
+	  return OSIP_BADPARAMETER;
+
   cseq->number = NULL;
   cseq->method = NULL;
 
   method = strchr (hvalue, ' ');        /* SEARCH FOR SPACE */
+  if (method == NULL)
+    return OSIP_SYNTAXERROR;
+
   end = hvalue + strlen (hvalue);
 
-  if (method == NULL)
-    return -1;
-
   if (method - hvalue + 1 < 2)
-    return -1;
+    return OSIP_SYNTAXERROR;
   cseq->number = (char *) osip_malloc (method - hvalue + 1);
   if (cseq->number == NULL)
-    return -1;
+    return OSIP_NOMEM;
   osip_clrncpy (cseq->number, hvalue, method - hvalue);
 
   if (end - method + 1 < 2)
-    return -1;
+    return OSIP_SYNTAXERROR;
   cseq->method = (char *) osip_malloc (end - method + 1);
   if (cseq->method == NULL)
-    return -1;
+    return OSIP_NOMEM;
   osip_clrncpy (cseq->method, method + 1, end - method);
 
-  return 0;                     /* ok */
+  return OSIP_SUCCESS;                     /* ok */
 }
 
 #ifndef MINISIZE
@@ -145,13 +148,13 @@ osip_cseq_to_str (const osip_cseq_t * cseq, char **dest)
 
   *dest = NULL;
   if ((cseq == NULL) || (cseq->number == NULL) || (cseq->method == NULL))
-    return -1;
+    return OSIP_BADPARAMETER;
   len = strlen (cseq->method) + strlen (cseq->number) + 2;
   *dest = (char *) osip_malloc (len);
   if (*dest == NULL)
-    return -1;
+    return OSIP_NOMEM;
   sprintf (*dest, "%s %s", cseq->number, cseq->method);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* deallocates a osip_cseq_t structure.  */
@@ -174,33 +177,33 @@ osip_cseq_clone (const osip_cseq_t * cseq, osip_cseq_t ** dest)
 
   *dest = NULL;
   if (cseq == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (cseq->method == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (cseq->number == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   i = osip_cseq_init (&cs);
   if (i != 0)
     {
       osip_cseq_free (cs);
-      return -1;
+      return i;
     }
   cs->method = osip_strdup (cseq->method);
   cs->number = osip_strdup (cseq->number);
 
   *dest = cs;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
 osip_cseq_match (osip_cseq_t * cseq1, osip_cseq_t * cseq2)
 {
   if (cseq1 == NULL || cseq2 == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (cseq1->number == NULL || cseq2->number == NULL
       || cseq1->method == NULL || cseq2->method == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   if (0 == strcmp (cseq1->number, cseq2->number))
     {
@@ -209,12 +212,12 @@ osip_cseq_match (osip_cseq_t * cseq1, osip_cseq_t * cseq2)
         {
           if (0 == strcmp (cseq1->method, "INVITE") ||
               0 == strcmp (cseq1->method, "ACK"))
-            return 0;
+            return OSIP_SUCCESS;
       } else
         {
           if (0 == strcmp (cseq1->method, cseq2->method))
-            return 0;
+            return OSIP_SUCCESS;
         }
     }
-  return -1;
+  return OSIP_UNDEFINED_ERROR;
 }
