@@ -27,25 +27,27 @@ int
 osip_list_init (osip_list_t * li)
 {
   if (li == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   memset (li, 0, sizeof (osip_list_t));
-  return 0;                     /* ok */
+  return OSIP_SUCCESS;                     /* ok */
 }
 
-int osip_list_clone (const osip_list_t * src, osip_list_t * dst, int *(*clone_func) (void *, void *))
+int osip_list_clone (const osip_list_t * src, osip_list_t * dst, int (*clone_func) (void *, void **))
 {
     void *data;
     void *data2;
     int pos=0;
+	int i;
     while (!osip_list_eol (src, pos))
       {
         data = osip_list_get (src, pos);
-        if (clone_func (data, &data2)!=0)
-	  return -1;
+		i = clone_func (data, &data2);
+        if (i!=0)
+			return i;
         osip_list_add (dst, data2, -1);
         pos++;
       }
-    return 0;
+    return OSIP_SUCCESS;
 }
 
 void
@@ -83,26 +85,19 @@ osip_list_ofchar_free (osip_list_t * li)
 int
 osip_list_size (const osip_list_t * li)
 {
-  /* 
-     Robin Nayathodan <roooot@softhome.net> 
-     N.K Electronics INDIA
+  if (li == NULL)
+    return OSIP_BADPARAMETER;
 
-     NULL Checks  
-   */
-
-  if (li != NULL)
-    return li->nb_elt;
-  else
-    return -1;
+  return li->nb_elt;
 }
 
 int
 osip_list_eol (const osip_list_t * li, int i)
 {
   if (li == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (i < li->nb_elt)
-    return 0;                   /* not end of list */
+    return OSIP_SUCCESS;                   /* not end of list */
   return 1;                     /* end of list */
 }
 
@@ -114,14 +109,14 @@ osip_list_add (osip_list_t * li, void *el, int pos)
   int i = 0;
 
   if (li == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   if (li->nb_elt == 0)
     {
 
       li->node = (__node_t *) osip_malloc (sizeof (__node_t));
       if (li->node == NULL)
-        return -1;
+        return OSIP_NOMEM;
       li->node->element = el;
       li->node->next = NULL;
       li->nb_elt++;
@@ -142,7 +137,7 @@ osip_list_add (osip_list_t * li, void *el, int pos)
         {
           /* leave the list unchanged */
           li->node = ntmp;
-          return -1;
+          return OSIP_NOMEM;
         }
       li->node->element = el;
       li->node->next = ntmp;
@@ -163,7 +158,7 @@ osip_list_add (osip_list_t * li, void *el, int pos)
     {
       ntmp->next = (__node_t *) osip_malloc (sizeof (__node_t));
       if (ntmp->next == NULL)
-        return -1;              /* leave the list unchanged */
+        return OSIP_NOMEM;              /* leave the list unchanged */
       ntmp = (__node_t *) ntmp->next;
       ntmp->element = el;
       ntmp->next = NULL;
@@ -180,7 +175,7 @@ osip_list_add (osip_list_t * li, void *el, int pos)
       {
         /* leave the list unchanged */
         ntmp->next = nextnode;
-        return -1;
+        return OSIP_NOMEM;
       }
     ntmp = (__node_t *) ntmp->next;
     ntmp->element = el;
@@ -222,7 +217,7 @@ osip_list_get_first (osip_list_t * li, osip_list_iterator_t * iterator)
   if (0 >= li->nb_elt)
     {
       iterator->actual = 0;
-      return 0;
+      return OSIP_SUCCESS;
     }
 
   iterator->actual = li->node;
@@ -247,7 +242,7 @@ osip_list_get_next (osip_list_iterator_t * iterator)
     }
 
   iterator->actual = 0;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* added by bennewit@cs.tu-berlin.de */
@@ -269,7 +264,7 @@ osip_list_iterator_remove (osip_list_iterator_t * iterator)
       return iterator->actual->element;
     }
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* return -1 if failed */
@@ -281,11 +276,11 @@ osip_list_remove (osip_list_t * li, int pos)
   int i = 0;
 
   if (li == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   if (pos < 0 || pos >= li->nb_elt)
     /* element does not exist */
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
 
   ntmp = li->node;              /* exist because nb_elt>0 */
 
