@@ -39,21 +39,21 @@ osip_message_set_proxy_authentication_info (osip_message_t * sip,
   int i;
 
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;
+    return OSIP_SUCCESS;
 
   i = osip_proxy_authentication_info_init (&(proxy_authentication_info));
   if (i != 0)
-    return -1;
+    return i;
   i = osip_proxy_authentication_info_parse (proxy_authentication_info, hvalue);
   if (i != 0)
     {
       osip_proxy_authentication_info_free (proxy_authentication_info);
-      return -1;
+      return i;
     }
   sip->message_property = 2;
 
   osip_list_add (&sip->proxy_authentication_infos, proxy_authentication_info, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 
@@ -71,7 +71,7 @@ osip_message_get_proxy_authentication_info (const osip_message_t * sip,
 
   *dest = NULL;
   if (osip_list_size (&sip->proxy_authentication_infos) <= pos)
-    return -1;                  /* does not exist */
+    return OSIP_UNDEFINED_ERROR;     /* does not exist */
 
   proxy_authentication_info = (osip_proxy_authentication_info_t *)
     osip_list_get (&sip->proxy_authentication_infos, pos);
