@@ -38,20 +38,20 @@ osip_message_set_proxy_authorization (osip_message_t * sip, const char *hvalue)
   int i;
 
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;
+    return OSIP_SUCCESS;
 
   i = osip_proxy_authorization_init (&proxy_authorization);
   if (i != 0)
-    return -1;
+    return i;
   i = osip_proxy_authorization_parse (proxy_authorization, hvalue);
   if (i != 0)
     {
       osip_proxy_authorization_free (proxy_authorization);
-      return -1;
+      return i;
     }
   sip->message_property = 2;
   osip_list_add (&sip->proxy_authorizations, proxy_authorization, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 #ifndef MINISIZE
@@ -63,7 +63,7 @@ osip_message_get_proxy_authorization (const osip_message_t * sip, int pos,
 
   *dest = NULL;
   if (osip_list_size (&sip->proxy_authorizations) <= pos)
-    return -1;                  /* does not exist */
+    return OSIP_UNDEFINED_ERROR;     /* does not exist */
   proxy_authorization =
     (osip_proxy_authorization_t *) osip_list_get (&sip->proxy_authorizations, pos);
   *dest = proxy_authorization;
