@@ -32,9 +32,9 @@ osip_www_authenticate_init (osip_www_authenticate_t ** dest)
   *dest =
     (osip_www_authenticate_t *) osip_malloc (sizeof (osip_www_authenticate_t));
   if (*dest == NULL)
-    return -1;
+    return OSIP_NOMEM;
   memset (*dest, 0, sizeof (osip_www_authenticate_t));
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* fills the www-authenticate header of message.               */
@@ -48,22 +48,22 @@ osip_message_set_www_authenticate (osip_message_t * sip, const char *hvalue)
   int i;
 
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;
+    return OSIP_SUCCESS;
 
   if (sip == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   i = osip_www_authenticate_init (&www_authenticate);
   if (i != 0)
-    return -1;
+    return i;
   i = osip_www_authenticate_parse (www_authenticate, hvalue);
   if (i != 0)
     {
       osip_www_authenticate_free (www_authenticate);
-      return -1;
+      return i;
     }
   sip->message_property = 2;
   osip_list_add (&sip->www_authenticates, www_authenticate, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -72,16 +72,16 @@ __osip_quoted_string_set (const char *name, const char *str,
 {
   *next = str;
   if (*result != NULL)
-    return 0;                   /* already parsed */
+    return OSIP_SUCCESS;                   /* already parsed */
   *next = NULL;
   while ((' ' == *str) || ('\t' == *str) || (',' == *str))
     if (*str)
       str++;
     else
-      return -1;                /* bad header format */
+      return OSIP_SYNTAXERROR;                /* bad header format */
 
   if (strlen (str) <= strlen (name))
-    return -1;                  /* bad header format... */
+    return OSIP_SYNTAXERROR;                  /* bad header format... */
   if (osip_strncasecmp (name, str, strlen (name)) == 0)
     {
       const char *quote1;
@@ -90,22 +90,22 @@ __osip_quoted_string_set (const char *name, const char *str,
       const char *hack = strchr (str, '=');
 
       if (hack == NULL)
-        return -1;
+        return OSIP_SYNTAXERROR;
 
       while (' ' == *(hack - 1))        /* get rid of extra spaces */
         hack--;
       if ((size_t) (hack - str) != strlen (name))
         {
           *next = str;
-          return 0;
+          return OSIP_SUCCESS;
         }
 
       quote1 = __osip_quote_find (str);
       if (quote1 == NULL)
-        return -1;              /* bad header format... */
+        return OSIP_SYNTAXERROR;              /* bad header format... */
       quote2 = __osip_quote_find (quote1 + 1);
       if (quote2 == NULL)
-        return -1;              /* bad header format... */
+        return OSIP_SYNTAXERROR;              /* bad header format... */
       if (quote2 - quote1 == 1)
         {
           /* this is a special case! The quote contains nothing! */
@@ -122,7 +122,7 @@ __osip_quoted_string_set (const char *name, const char *str,
             }                   /* skip LWS */
           *next = NULL;
           if (*tmp == '\0')     /* end of header detected */
-            return 0;
+            return OSIP_SUCCESS;
           if (*tmp != '\t' && *tmp != ' ')
             /* LWS here ? */
             *next = tmp;
@@ -132,14 +132,14 @@ __osip_quoted_string_set (const char *name, const char *str,
                 {
                 }
               if (*tmp == '\0') /* end of header detected */
-                return 0;
+                return OSIP_SUCCESS;
               *next = tmp;
             }
-          return 0;
+          return OSIP_SUCCESS;
         }
       *result = (char *) osip_malloc (quote2 - quote1 + 3);
       if (*result == NULL)
-        return -1;
+        return OSIP_NOMEM;
       osip_strncpy (*result, quote1, quote2 - quote1 + 1);
       tmp = quote2 + 1;         /* next element start here */
       for (; *tmp == ' ' || *tmp == '\t'; tmp++)
@@ -150,7 +150,7 @@ __osip_quoted_string_set (const char *name, const char *str,
         }                       /* skip LWS */
       *next = NULL;
       if (*tmp == '\0')         /* end of header detected */
-        return 0;
+        return OSIP_SUCCESS;
       if (*tmp != '\t' && *tmp != ' ')
         /* LWS here ? */
         *next = tmp;
@@ -160,12 +160,12 @@ __osip_quoted_string_set (const char *name, const char *str,
             {
             }
           if (*tmp == '\0')     /* end of header detected */
-            return 0;
+            return OSIP_SUCCESS;
           *next = tmp;
         }
   } else
     *next = str;                /* wrong header asked! */
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -177,21 +177,21 @@ __osip_token_set (const char *name, const char *str, char **result,
 
   *next = str;
   if (*result != NULL)
-    return 0;                   /* already parsed */
+    return OSIP_SUCCESS;                   /* already parsed */
   *next = NULL;
 
   beg = strchr (str, '=');
   if (beg == NULL)
-    return -1;                  /* bad header format... */
+    return OSIP_SYNTAXERROR;                  /* bad header format... */
 
   if (strlen (str) < 6)
-    return 0;                   /* end of header... */
+    return OSIP_SUCCESS;                   /* end of header... */
 
   while ((' ' == *str) || ('\t' == *str) || (',' == *str))
     if (*str)
       str++;
     else
-      return -1;                /* bad header format */
+      return OSIP_SYNTAXERROR;                /* bad header format */
 
   if (osip_strncasecmp (name, str, strlen (name)) == 0)
     {
@@ -202,10 +202,10 @@ __osip_token_set (const char *name, const char *str, char **result,
         end = str + strlen (str);       /* This is the end of the header */
 
       if (end - beg < 2)
-        return -1;
+        return OSIP_SYNTAXERROR;
       *result = (char *) osip_malloc (end - beg);
       if (*result == NULL)
-        return -1;
+        return OSIP_NOMEM;
       osip_clrncpy (*result, beg + 1, end - beg - 1);
 
       /* make sure the element does not contain more parameter */
@@ -218,7 +218,7 @@ __osip_token_set (const char *name, const char *str, char **result,
         }                       /* skip LWS */
       *next = NULL;
       if (*tmp == '\0')         /* end of header detected */
-        return 0;
+        return OSIP_SUCCESS;
       if (*tmp != '\t' && *tmp != ' ')
         /* LWS here ? */
         *next = tmp;
@@ -228,12 +228,12 @@ __osip_token_set (const char *name, const char *str, char **result,
             {
             }
           if (*tmp == '\0')     /* end of header detected */
-            return 0;
+            return OSIP_SUCCESS;
           *next = tmp;
         }
   } else
     *next = str;                /* next element start here */
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* fills the www-authenticate strucuture.                      */
@@ -249,80 +249,88 @@ osip_www_authenticate_parse (osip_www_authenticate_t * wwwa, const char *hvalue)
 {
   const char *space;
   const char *next = NULL;
+  int i;
 
   space = strchr (hvalue, ' '); /* SEARCH FOR SPACE */
   if (space == NULL)
-    return -1;
+    return OSIP_SYNTAXERROR;
 
   if (space - hvalue + 1 < 2)
-    return -1;
+    return OSIP_SYNTAXERROR;
   wwwa->auth_type = (char *) osip_malloc (space - hvalue + 1);
   if (wwwa->auth_type == NULL)
-    return -1;
+    return OSIP_NOMEM;
   osip_strncpy (wwwa->auth_type, hvalue, space - hvalue);
 
   for (;;)
     {
       int parse_ok = 0;
 
-      if (__osip_quoted_string_set ("realm", space, &(wwwa->realm), &next))
-        return -1;
+	  i = __osip_quoted_string_set ("realm", space, &(wwwa->realm), &next);
+      if (i!=0)
+        return i;
       if (next == NULL)
-        return 0;               /* end of header detected! */
+        return OSIP_SUCCESS;               /* end of header detected! */
       else if (next != space)
         {
           space = next;
           parse_ok++;
         }
-      if (__osip_quoted_string_set ("domain", space, &(wwwa->domain), &next))
-        return -1;
+	  i = __osip_quoted_string_set ("domain", space, &(wwwa->domain), &next);
+      if (i!=0)
+        return i;
       if (next == NULL)
-        return 0;               /* end of header detected! */
+        return OSIP_SUCCESS;               /* end of header detected! */
       else if (next != space)
         {
           space = next;
           parse_ok++;
         }
-      if (__osip_quoted_string_set ("nonce", space, &(wwwa->nonce), &next))
-        return -1;
+	  i = __osip_quoted_string_set ("nonce", space, &(wwwa->nonce), &next);
+      if (i!=0)
+        return i;
       if (next == NULL)
-        return 0;               /* end of header detected! */
+        return OSIP_SUCCESS;               /* end of header detected! */
       else if (next != space)
         {
           space = next;
           parse_ok++;
         }
-      if (__osip_quoted_string_set ("opaque", space, &(wwwa->opaque), &next))
-        return -1;
+	  i = __osip_quoted_string_set ("opaque", space, &(wwwa->opaque), &next);
+      if (i!=0)
+        return i;
       if (next == NULL)
-        return 0;               /* end of header detected! */
+        return OSIP_SUCCESS;               /* end of header detected! */
       else if (next != space)
         {
           space = next;
           parse_ok++;
         }
-      if (__osip_token_set ("stale", space, &(wwwa->stale), &next))
-        return -1;
+	  i = __osip_token_set ("stale", space, &(wwwa->stale), &next);
+      if (i!=0)
+        return i;
       if (next == NULL)
-        return 0;               /* end of header detected! */
+        return OSIP_SUCCESS;               /* end of header detected! */
       else if (next != space)
         {
           space = next;
           parse_ok++;
         }
-      if (__osip_token_set ("algorithm", space, &(wwwa->algorithm), &next))
-        return -1;
+	  i = __osip_token_set ("algorithm", space, &(wwwa->algorithm), &next);
+      if (i!=0)
+        return i;
       if (next == NULL)
-        return 0;               /* end of header detected! */
+        return OSIP_SUCCESS;               /* end of header detected! */
       else if (next != space)
         {
           space = next;
           parse_ok++;
         }
-      if (__osip_quoted_string_set ("qop", space, &(wwwa->qop_options), &next))
-        return -1;
+	  i = __osip_quoted_string_set ("qop", space, &(wwwa->qop_options), &next);
+      if (i!=0)
+        return i;
       if (next == NULL)
-        return 0;               /* end of header detected! */
+        return OSIP_SUCCESS;               /* end of header detected! */
       else if (next != space)
         {
           space = next;
@@ -336,28 +344,28 @@ osip_www_authenticate_parse (osip_www_authenticate_t * wwwa, const char *hvalue)
           /* parameter not understood!!! I'm too lazy to handle IT */
           /* let's simply bypass it */
           if (strlen (space) < 1)
-            return 0;
+            return OSIP_SUCCESS;
           tmp = strchr (space + 1, ',');
           if (tmp == NULL)      /* it was the last header */
-            return 0;
+            return OSIP_SUCCESS;
           quote1 = __osip_quote_find (space);
           if ((quote1 != NULL) && (quote1 < tmp))       /* this may be a quoted string! */
             {
               quote2 = __osip_quote_find (quote1 + 1);
               if (quote2 == NULL)
-                return -1;      /* bad header format... */
+                return OSIP_SYNTAXERROR;      /* bad header format... */
               if (tmp < quote2) /* the comma is inside the quotes! */
                 space = strchr (quote2, ',');
               else
                 space = tmp;
               if (space == NULL)        /* it was the last header */
-                return 0;
+                return OSIP_SUCCESS;
           } else
             space = tmp;
           /* continue parsing... */
         }
     }
-  return 0;                     /* ok */
+  return OSIP_SUCCESS;                     /* ok */
 }
 
 #ifndef MINISIZE
@@ -372,7 +380,7 @@ osip_message_get_www_authenticate (const osip_message_t * sip, int pos,
 
   *dest = NULL;
   if (osip_list_size (&sip->www_authenticates) <= pos)
-    return -1;                  /* does not exist */
+    return OSIP_UNDEFINED_ERROR;     /* does not exist */
 
   www_authenticate =
     (osip_www_authenticate_t *) osip_list_get (&sip->www_authenticates, pos);
@@ -499,7 +507,7 @@ osip_www_authenticate_to_str (const osip_www_authenticate_t * wwwa, char **dest)
 
   *dest = NULL;
   if ((wwwa == NULL) || (wwwa->auth_type == NULL))
-    return -1;
+    return OSIP_BADPARAMETER;
 
   len = strlen (wwwa->auth_type) + 1;
 
@@ -521,7 +529,7 @@ osip_www_authenticate_to_str (const osip_www_authenticate_t * wwwa, char **dest)
 
   tmp = (char *) osip_malloc (len);
   if (tmp == NULL)
-    return -1;
+    return OSIP_NOMEM;
   *dest = tmp;
 
   tmp = osip_str_append (tmp, wwwa->auth_type);
@@ -570,7 +578,7 @@ osip_www_authenticate_to_str (const osip_www_authenticate_t * wwwa, char **dest)
         (*dest)[len] = ' ';
     }
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* deallocates a osip_www_authenticate_t structure.  */
@@ -602,29 +610,69 @@ osip_www_authenticate_clone (const osip_www_authenticate_t * wwwa,
 
   *dest = NULL;
   if (wwwa == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (wwwa->auth_type == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   i = osip_www_authenticate_init (&wa);
-  if (i == -1)                  /* allocation failed */
-    return -1;
+  if (i != 0)                  /* allocation failed */
+    return i;
   wa->auth_type = osip_strdup (wwwa->auth_type);
+  if (wa->auth_type==NULL && wwwa->auth_type!=NULL)
+  {
+	  osip_www_authenticate_free (wa);
+	  return OSIP_NOMEM;
+  }
   if (wwwa->realm != NULL)
     wa->realm = osip_strdup (wwwa->realm);
+  if (wa->realm==NULL && wwwa->realm!=NULL)
+  {
+	  osip_www_authenticate_free (wa);
+	  return OSIP_NOMEM;
+  }
   if (wwwa->domain != NULL)
     wa->domain = osip_strdup (wwwa->domain);
+  if (wa->domain==NULL && wwwa->domain!=NULL)
+  {
+	  osip_www_authenticate_free (wa);
+	  return OSIP_NOMEM;
+  }
   if (wwwa->nonce != NULL)
     wa->nonce = osip_strdup (wwwa->nonce);
+  if (wa->nonce==NULL && wwwa->nonce!=NULL)
+  {
+	  osip_www_authenticate_free (wa);
+	  return OSIP_NOMEM;
+  }
   if (wwwa->opaque != NULL)
     wa->opaque = osip_strdup (wwwa->opaque);
+  if (wa->opaque==NULL && wwwa->opaque!=NULL)
+  {
+	  osip_www_authenticate_free (wa);
+	  return OSIP_NOMEM;
+  }
   if (wwwa->stale != NULL)
     wa->stale = osip_strdup (wwwa->stale);
+  if (wa->stale==NULL && wwwa->stale!=NULL)
+  {
+	  osip_www_authenticate_free (wa);
+	  return OSIP_NOMEM;
+  }
   if (wwwa->algorithm != NULL)
     wa->algorithm = osip_strdup (wwwa->algorithm);
+  if (wa->algorithm==NULL && wwwa->algorithm!=NULL)
+  {
+	  osip_www_authenticate_free (wa);
+	  return OSIP_NOMEM;
+  }
   if (wwwa->qop_options != NULL)
     wa->qop_options = osip_strdup (wwwa->qop_options);
+  if (wa->qop_options==NULL && wwwa->qop_options!=NULL)
+  {
+	  osip_www_authenticate_free (wa);
+	  return OSIP_NOMEM;
+  }
 
   *dest = wa;
-  return 0;
+  return OSIP_SUCCESS;
 }
